@@ -7,11 +7,11 @@ from pydantic import BaseModel
 if sys.version_info >= (3, 8):
     # pyright: reportUnusedImport=false
     from typing import (  # pylint: disable=no-name-in-module, unused-import
-        TypedDict,
-        Literal,
+        TypedDict as TypedDict,
+        Literal as Literal,
     )
 else:
-    from typing_extensions import TypedDict, Literal
+    from typing_extensions import TypedDict as TypedDict, Literal as Literal
 
 
 Method = Literal['GET', 'POST']
